package com.qmth.cqb.paper.web;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import io.swagger.annotations.ApiOperation;

import org.apache.commons.collections4.map.HashedMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import cn.com.qmth.examcloud.common.uac.entity.AccessUser;

import com.qmth.cqb.paper.model.ExtractConfig;
import com.qmth.cqb.paper.service.ExtractConfigService;


/**
 * 
 * @author  	chenken
 * @date    	2017年4月14日 下午6:05:37
 * @company 	QMTH
 * @description ExtractConfigController.java
 */
@Controller
@RequestMapping("${api_cqb}/")
public class ExtractConfigController {
	@Autowired
	private ExtractConfigService extractConfigService;
	
	@ApiOperation(value = "根据考试ID和课程ID获取调卷规则", notes = "根据考试ID和课程ID获取调卷规则")
    @GetMapping(value = "/extractConfig/{examId}/{courseCode}")
	public ResponseEntity<ExtractConfig> findExtractConfig(@PathVariable Long examId,@PathVariable String courseCode){
		ExtractConfig condition = new ExtractConfig();
		condition.setExamId(examId);
		condition.setCourseCode(courseCode);
		ExtractConfig extractConfig = extractConfigService.findConfig(condition);
		return new ResponseEntity<ExtractConfig>(extractConfig,HttpStatus.OK);
	}
	
	@ApiOperation(value = "根据ID获取调卷规则", notes = "根据ID获取调卷规则")
    @GetMapping(value = "/extractConfig/{id}")
	public ResponseEntity<ExtractConfig> findExtractConfigById(@PathVariable String id){
		ExtractConfig extractConfig = extractConfigService.findConfigById(id);
		return new ResponseEntity<ExtractConfig>(extractConfig,HttpStatus.OK);
	} 
	
	@ApiOperation(value = "保存调卷规则", notes = "保存调卷规则")
    @PutMapping(value = "/extractConfig")
	public ResponseEntity<Map<String,Object>> saveExtractConfig(HttpServletRequest request,@RequestBody ExtractConfig extractConfig){
		Map<String,Object> paramsMap = new HashedMap<String,Object>();
		try{
			AccessUser user = (AccessUser) request.getAttribute("accessUser");
			extractConfig.setOrgId(user.getOrgId()+"");
			extractConfigService.saveExtractConfig(extractConfig);
			paramsMap.put("returnMsg", "保存成功");
			paramsMap.put("status", "success");
		}catch(Exception e){
			paramsMap.put("returnMsg", "保存失败");
			paramsMap.put("status", "failed");
		}
		return new ResponseEntity<Map<String,Object>>(paramsMap,HttpStatus.OK);
	}
	
	@ApiOperation(value = "根据调卷规则生成试卷", notes = "根据调卷规则生成试卷")
    @PutMapping(value = "/makePaperByConfig/{configId}")
	public ResponseEntity<Map<String,Object>> makePaperByConfig(@PathVariable String configId){
		Map<String,Object> paramsMap = new HashedMap<String,Object>();
		try{
			extractConfigService.makePaperByConfig(configId);
			paramsMap.put("returnMsg", "试卷生成成功");
			paramsMap.put("status", "success");
		}catch(Exception e){
			paramsMap.put("returnMsg", "试卷生成失败");
			paramsMap.put("status", "failed");
		}
		return new ResponseEntity<Map<String,Object>>(paramsMap,HttpStatus.OK);
	}
}	
